@@ -25,7 +25,12 @@
 #ifndef EDITOR_CONTROL_FACTORY_H_
 #define EDITOR_CONTROL_FACTORY_H_
 
+#include <config.h>
+#include <bonobo.h>
+
 #define CONTROL_FACTORY_ID "OAFIID:GNOME_GtkHTML_Editor_Factory:" EDITOR_API_VERSION
 #define CONTROL_ID         "OAFIID:GNOME_GtkHTML_Editor:" EDITOR_API_VERSION
 
+BonoboObject *editor_control_factory (BonoboGenericFactory *factory, const gchar *component_id, gpointer closure);
+
 #endif
