@@ -21,7 +21,11 @@
 */
 
 #include <config.h> 
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include "search.h"
@@ -91,8 +95,8 @@ search_dialog_response (GtkDialog *dialog, gint response_id, GtkHTMLSearchDialog
 	case GTK_RESPONSE_DELETE_EVENT:
 	case GTK_RESPONSE_CLOSE:
 	case GTK_RESPONSE_CANCEL:
-		gtk_dialog_set_response_sensitive (d->dialog, 0, TRUE);
-		gtk_widget_hide (GTK_WIDGET (d->dialog));
+		d->cd->search_dialog = NULL;
+		gtk_html_search_dialog_destroy (d);
 		gtk_widget_grab_focus (GTK_WIDGET (d->cd->html));
 		break;
 	}
@@ -103,7 +107,6 @@ gtk_html_search_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 {
 	GtkHTMLSearchDialog *dialog = g_new (GtkHTMLSearchDialog, 1);
 	GtkWidget *hbox, *vbox;
-
 	/* we use CANCEL response for close, because we want Esc to close the dialog - see gtkdialog.c */
 	dialog->dialog         = GTK_DIALOG (gtk_dialog_new_with_buttons (_("Find"), NULL, 0,
 									  GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
@@ -116,6 +119,8 @@ gtk_html_search_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 	dialog->html           = html;
 	dialog->cd             = cd;
 
+	atk_object_set_description (gtk_widget_get_accessible (dialog->entry), _("Input the words you want to search here"));
+
 	hbox = gtk_hbox_new (FALSE, 6);
 
 	if (cd->search_text)
@@ -164,13 +169,6 @@ void
 search (GtkHTMLControlData *cd)
 {
 	RUN_DIALOG (search, _("Find"));
-
-	g_assert (cd->search_dialog && cd->search_dialog->dialog);
-
-	if (!GTK_WIDGET_VISIBLE (cd->search_dialog->dialog)) {
-		gtk_html_search_dialog_destroy (cd->search_dialog);
-		cd->search_dialog = NULL;
-	}
 }
 
 void
