@@ -222,7 +222,6 @@ get_body (HTMLEngine *e)
 	gchar *bg;
 	gchar *bg_image;
 	gchar *link;
-	char *dir = NULL;
 	gchar *lm, *rm, *tm, *bm;
 	gchar *url = NULL;
 
@@ -235,12 +234,6 @@ get_body (HTMLEngine *e)
 						     (e->widget, ((HTMLImagePointer *) e->bgPixmapPtr)->url))
 		: g_strdup ("");
 	g_free (url);
-	if (HTML_CLUEV (e->clue)->dir != HTML_DIRECTION_DERIVED) {
-		if (HTML_CLUEV (e->clue)->dir == HTML_DIRECTION_RTL)
-			dir = " DIR=RTL";
-		else
-			dir = " DIR=LTR";
-	}
 
 	lm = e->leftBorder != LEFT_BORDER ? g_strdup_printf (" LEFTMARGIN=\"%d\"", e->leftBorder) : g_strdup ("");
 	rm = e->rightBorder != RIGHT_BORDER ? g_strdup_printf (" RIGHTMARGIN=\"%d\"", e->rightBorder) : g_strdup ("");
@@ -393,17 +386,22 @@ html_engine_save_buffer_receiver (const HTMLEngine *engine,
 	return TRUE;
 }
 	
-void
-html_engine_save_buffer_free (HTMLEngineSaveState *state)
+char *
+html_engine_save_buffer_free (HTMLEngineSaveState *state, gboolean free_string)
 {
 	GString *string;
+	char *rv = NULL;
 
-	g_return_if_fail (state != NULL);
+	g_return_val_if_fail (state != NULL, NULL);
 	string = (GString *)state->user_data;
 
-	g_string_free (string, TRUE);
+	if (!free_string)
+		rv = string->str;
+	g_string_free (string, free_string);
 
 	g_free (state);
+
+	return rv;
 }
 
 guchar *
